.. currentmodule:: pvlib


Inverter models (DC to AC conversion)
-------------------------------------

.. autosummary::
   :toctree: ../generated/

   pvsystem.PVSystem.get_ac
   inverter.sandia
   inverter.sandia_multi
   inverter.adr
   inverter.pvwatts
   inverter.pvwatts_multi

Functions for fitting inverter models

.. autosummary::
   :toctree: ../generated/

   inverter.fit_sandia
